@@ -1,10 +1,13 @@
+"""External API for Zeno."""
+
 import functools
-from dataclasses import dataclass
-from typing import Dict
+from typing import Callable, Dict, List
+
+from pandas import DataFrame
+from pydantic import BaseModel
 
 
-@dataclass
-class ZenoOptions:
+class ZenoOptions(BaseModel):
     """Parameters passed to Zeno test functions.
 
     Args:
@@ -30,6 +33,30 @@ class ZenoOptions:
     output_path: str
 
 
+class ZenoParameters(BaseModel):
+    """Options passed to the backend processing pipeline."""
+
+    metadata: DataFrame
+    view: str = ""
+    functions: List[Callable] = []
+    models: List[str] = []
+    id_column: str = ""
+    data_column: str = ""
+    label_column: str = ""
+    data_path: str = ""
+    label_path: str = ""
+    batch_size: int = 1
+    cache_path: str = ""
+    editable: bool = True
+    serve: bool = True
+    samples: int = 30
+    port: int = 8000
+    host: str = "localhost"
+
+    class Config:
+        arbitrary_types_allowed = True
+
+
 def model(func):
     @functools.wraps(func)
     def _wrapper(*args, **kwargs):
